@@ -38,6 +38,8 @@ function got_mod_rewrite() {
  *
  * @since 3.7.0
  *
+ * @global bool $is_nginx
+ *
  * @return bool Whether the server supports URL rewriting.
  */
 function got_url_rewrite() {
@@ -58,8 +60,8 @@ function got_url_rewrite() {
  *
  * @since 1.5.0
  *
- * @param unknown_type $filename
- * @param unknown_type $marker
+ * @param string $filename
+ * @param string $marker
  * @return array An array of strings from a file (.htaccess ) from between BEGIN and END markers.
  */
 function extract_from_markers( $filename, $marker ) {
@@ -94,9 +96,9 @@ function extract_from_markers( $filename, $marker ) {
  *
  * @since 1.5.0
  *
- * @param unknown_type $filename
- * @param unknown_type $marker
- * @param unknown_type $insertion
+ * @param string $filename
+ * @param string $marker
+ * @param array  $insertion
  * @return bool True on write success, false on failure.
  */
 function insert_with_markers( $filename, $marker, $insertion ) {
@@ -153,6 +155,8 @@ function insert_with_markers( $filename, $marker, $insertion ) {
  * blank out old rules.
  *
  * @since 1.5.0
+ *
+ * @global WP_Rewrite $wp_rewrite
  */
 function save_mod_rewrite_rules() {
 	if ( is_multisite() )
@@ -183,6 +187,8 @@ function save_mod_rewrite_rules() {
  *
  * @since 2.8.0
  *
+ * @global WP_Rewrite $wp_rewrite
+ *
  * @return bool True if web.config was updated successfully
  */
 function iis7_save_url_rewrite_rules(){
@@ -211,7 +217,7 @@ function iis7_save_url_rewrite_rules(){
  *
  * @since 1.5.0
  *
- * @param unknown_type $file
+ * @param string $file
  */
 function update_recently_edited( $file ) {
 	$oldfiles = (array ) get_option( 'recently_edited' );
@@ -244,10 +250,6 @@ function update_home_siteurl( $old_value, $value ) {
 	flush_rewrite_rules();
 }
 
-add_action( 'update_option_home', 'update_home_siteurl', 10, 2 );
-add_action( 'update_option_siteurl', 'update_home_siteurl', 10, 2 );
-add_action( 'update_option_page_on_front', 'update_home_siteurl', 10, 2 );
-
 /**
  * Shorten an URL, to be used as link text
  *
@@ -294,7 +296,7 @@ function wp_reset_vars( $vars ) {
  *
  * @since 2.1.0
  *
- * @param unknown_type $message
+ * @param string|WP_Error $message
  */
 function show_message($message) {
 	if ( is_wp_error($message) ){
@@ -308,6 +310,12 @@ function show_message($message) {
 	flush();
 }
 
+/**
+ * @since 2.8.0
+ *
+ * @param string $content
+ * @return array
+ */
 function wp_doc_link_parse( $content ) {
 	if ( !is_string( $content ) || empty( $content ) )
 		return array();
@@ -615,6 +623,8 @@ function saveDomDocument($doc, $filename) {
  * Display the default admin color scheme picker (Used in user-edit.php)
  *
  * @since 3.0.0
+ *
+ * @global array $_wp_admin_css_colors
  */
 function admin_color_scheme_picker( $user_id ) {
 	global $_wp_admin_css_colors;
@@ -643,7 +653,7 @@ function admin_color_scheme_picker( $user_id ) {
 			<div class="color-option <?php echo ( $color == $current_color ) ? 'selected' : ''; ?>">
 				<input name="admin_color" id="admin_color_<?php echo esc_attr( $color ); ?>" type="radio" value="<?php echo esc_attr( $color ); ?>" class="tog" <?php checked( $color, $current_color ); ?> />
 				<input type="hidden" class="css_url" value="<?php echo esc_url( $color_info->url ); ?>" />
-				<input type="hidden" class="icon_colors" value="<?php echo esc_attr( json_encode( array( 'icons' => $color_info->icon_colors ) ) ); ?>" />
+				<input type="hidden" class="icon_colors" value="<?php echo esc_attr( wp_json_encode( array( 'icons' => $color_info->icon_colors ) ) ); ?>" />
 				<label for="admin_color_<?php echo esc_attr( $color ); ?>"><?php echo esc_html( $color_info->name ); ?></label>
 				<table class="color-palette">
 					<tr>
@@ -668,6 +678,10 @@ function admin_color_scheme_picker( $user_id ) {
 	<?php
 }
 
+/**
+ *
+ * @global array $_wp_admin_css_colors
+ */
 function wp_color_scheme_settings() {
 	global $_wp_admin_css_colors;
 
@@ -684,13 +698,15 @@ function wp_color_scheme_settings() {
 		$icon_colors = $_wp_admin_css_colors['fresh']->icon_colors;
 	} else {
 		// Fall back to the default set of icon colors if the default scheme is missing.
-		$icon_colors = array( 'base' => '#999', 'focus' => '#2ea2cc', 'current' => '#fff' );
+		$icon_colors = array( 'base' => '#999', 'focus' => '#00a0d2', 'current' => '#fff' );
 	}
 
-	echo '<script type="text/javascript">var _wpColorScheme = ' . json_encode( array( 'icons' => $icon_colors ) ) . ";</script>\n";
+	echo '<script type="text/javascript">var _wpColorScheme = ' . wp_json_encode( array( 'icons' => $icon_colors ) ) . ";</script>\n";
 }
-add_action( 'admin_head', 'wp_color_scheme_settings' );
 
+/**
+ * @since 3.3.0
+ */
 function _ipad_meta() {
 	if ( wp_is_mobile() ) {
 		?>
@@ -698,7 +714,6 @@ function _ipad_meta() {
 		<?php
 	}
 }
-add_action('admin_head', '_ipad_meta');
 
 /**
  * Check lock status for posts displayed on the Posts screen
@@ -729,7 +744,6 @@ function wp_check_locked_posts( $response, $data, $screen_id ) {
 
 	return $response;
 }
-add_filter( 'heartbeat_received', 'wp_check_locked_posts', 10, 3 );
 
 /**
  * Check lock status on the New/Edit Post screen and refresh the lock
@@ -768,7 +782,6 @@ function wp_refresh_post_lock( $response, $data, $screen_id ) {
 
 	return $response;
 }
-add_filter( 'heartbeat_received', 'wp_refresh_post_lock', 10, 3 );
 
 /**
  * Check nonce expiration on the New/Edit Post screen and refresh if needed
@@ -780,35 +793,36 @@ function wp_refresh_post_nonces( $response, $data, $screen_id ) {
 		$received = $data['wp-refresh-post-nonces'];
 		$response['wp-refresh-post-nonces'] = array( 'check' => 1 );
 
-		if ( ! $post_id = absint( $received['post_id'] ) )
+		if ( ! $post_id = absint( $received['post_id'] ) ) {
 			return $response;
-
-		if ( ! current_user_can( 'edit_post', $post_id ) || empty( $received['post_nonce'] ) )
-			return $response;
-
-		if ( 2 === wp_verify_nonce( $received['post_nonce'], 'update-post_' . $post_id ) ) {
-			$response['wp-refresh-post-nonces'] = array(
-				'replace' => array(
-					'getpermalinknonce' => wp_create_nonce('getpermalink'),
-					'samplepermalinknonce' => wp_create_nonce('samplepermalink'),
-					'closedpostboxesnonce' => wp_create_nonce('closedpostboxes'),
-					'_ajax_linking_nonce' => wp_create_nonce( 'internal-linking' ),
-					'_wpnonce' => wp_create_nonce( 'update-post_' . $post_id ),
-				),
-				'heartbeatNonce' => wp_create_nonce( 'heartbeat-nonce' ),
-			);
 		}
+
+		if ( ! current_user_can( 'edit_post', $post_id ) ) {
+			return $response;
+		}
+
+		$response['wp-refresh-post-nonces'] = array(
+			'replace' => array(
+				'getpermalinknonce' => wp_create_nonce('getpermalink'),
+				'samplepermalinknonce' => wp_create_nonce('samplepermalink'),
+				'closedpostboxesnonce' => wp_create_nonce('closedpostboxes'),
+				'_ajax_linking_nonce' => wp_create_nonce( 'internal-linking' ),
+				'_wpnonce' => wp_create_nonce( 'update-post_' . $post_id ),
+			),
+			'heartbeatNonce' => wp_create_nonce( 'heartbeat-nonce' ),
+		);
 	}
 
 	return $response;
 }
-add_filter( 'heartbeat_received', 'wp_refresh_post_nonces', 10, 3 );
 
 /**
  * Disable suspension of Heartbeat on the Add/Edit Post screens.
  *
  * @since 3.8.0
  *
+ * @global string $pagenow
+ *
  * @param array $settings An array of Heartbeat settings.
  * @return array Filtered Heartbeat settings.
  */
@@ -821,7 +835,6 @@ function wp_heartbeat_set_suspension( $settings ) {
 
 	return $settings;
 }
-add_filter( 'heartbeat_settings', 'wp_heartbeat_set_suspension' );
 
 /**
  * Autosave with heartbeat
@@ -846,8 +859,6 @@ function heartbeat_autosave( $response, $data ) {
 
 	return $response;
 }
-// Run later as we have to set DOING_AUTOSAVE for back-compat
-add_filter( 'heartbeat_received', 'heartbeat_autosave', 500, 2 );
 
 /**
  * Disables autocomplete on the 'post' form (Add/Edit Post screens) for WebKit browsers,
@@ -855,6 +866,9 @@ add_filter( 'heartbeat_received', 'heartbeat_autosave', 500, 2 );
  * when the user navigates to it with the browser's Back button. See #28037
  *
  * @since 4.0
+ *
+ * @global bool $is_safari
+ * @global bool $is_chrome
  */
 function post_form_autocomplete_off() {
 	global $is_safari, $is_chrome;
@@ -864,4 +878,46 @@ function post_form_autocomplete_off() {
 	}
 }
 
-add_action( 'post_edit_form_tag', 'post_form_autocomplete_off' );
+/**
+ * Remove single-use URL parameters and create canonical link based on new URL.
+ *
+ * Remove specific query string parameters from a URL, create the canonical link,
+ * put it in the admin header, and change the current URL to match.
+ *
+ * @since 4.2.0
+ */
+function wp_admin_canonical_url() {
+	$removable_query_args = array(
+		'message', 'settings-updated', 'saved',
+		'update', 'updated', 'activated',
+		'activate', 'deactivate', 'locked',
+		'deleted', 'trashed', 'untrashed',
+		'enabled', 'disabled', 'skipped',
+		'spammed', 'unspammed',
+	);
+
+	/**
+	 * Filter the list of URL parameters to remove.
+	 *
+	 * @since 4.2.0
+	 *
+	 * @param array $removable_query_args An array of parameters to remove from the URL.
+	 */
+	$removable_query_args = apply_filters( 'removable_query_args', $removable_query_args );
+
+	if ( empty( $removable_query_args ) ) {
+		return;
+	}
+
+	// Ensure we're using an absolute URL.
+	$current_url  = set_url_scheme( 'http://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'] );
+	$filtered_url = remove_query_arg( $removable_query_args, $current_url );
+	?>
+	<link id="wp-admin-canonical" rel="canonical" href="<?php echo esc_url( $filtered_url ); ?>" />
+	<script>
+		if ( window.history.replaceState ) {
+			window.history.replaceState( null, null, document.getElementById( 'wp-admin-canonical' ).href + window.location.hash );
+		}
+	</script>
+<?php
+}
